@@ -15,7 +15,7 @@ checkInstalledVersion()
   # version of DART being installed has to be greater than the current DART version
   if [ -f ${DARTMANIFEST} ]; then
       DARTPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${DARTMANIFEST})
-      DARTCURRVERSION=4.9.04043
+      DARTCURRVERSION=4.10.01075
 
       if [ $(version $DARTCURRVERSION) -le $(version $DARTPREVVERSION) ]; then
         failed=true
@@ -50,7 +50,7 @@ UNINSTALL="${VPNBIN}/dart_uninstall.sh"
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.9.04043-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.01075-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
 
 DARTMANIFEST="${INSTPREFIX}/ACManifestDART.xml"
 
@@ -142,8 +142,8 @@ if [ "${TEMPDIR}" != "." ]; then
 
   echo "Extracting installation files to ${TARFILE}..."
   echo "Extracting installation files to ${TARFILE}..." >> /tmp/${LOGFNAME}
-  # "head --bytes=-1" used to remove '\n' prior to MARKER_END
-  head -n ${MARKER_END} $0 | tail -n +${MARKER} | head --bytes=-1 2>> /tmp/${LOGFNAME} > ${TARFILE} || exit 1
+
+  head -n ${MARKER_END} $0 | tail -n +${MARKER} | head -c -1 2>> /tmp/${LOGFNAME} > ${TARFILE} || exit 1
 
   echo "Unarchiving installation files to ${TEMPDIR}..."
   echo "Unarchiving installation files to ${TEMPDIR}..." >> /tmp/${LOGFNAME}
@@ -255,6 +255,13 @@ else
     echo "${NEWTEMP}/Posture.xml does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/ISEPosture.xml" ]; then
+    echo "Installing "${NEWTEMP}/ISEPosture.xml >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 444 ${NEWTEMP}/ISEPosture.xml ${CONFIGDIR} || exit 1
+else
+    echo "${NEWTEMP}/ISEPosture.xml does not exist. It will not be installed."
+fi
+
 if [ -f "${NEWTEMP}/NetworkVisibility.xml" ]; then
     echo "Installing "${NEWTEMP}/NetworkVisibility.xml >> /tmp/${LOGFNAME}
     ${INSTALL} -o root -m 444 ${NEWTEMP}/NetworkVisibility.xml ${CONFIGDIR} || exit 1
