@@ -14,7 +14,7 @@ checkVersionFeasibilityWithStandaloneNVM()
   failed=false
   # version of VPN being installed has to be greater than the installed standalone NVM version
   if [ -f ${NVMMANIFEST} ]; then
-      VPNVERSION=4.9.04043
+      VPNVERSION=4.10.01075
       NVMVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
 
       if [ $(version $VPNVERSION) -lt $(version $NVMVERSION) ]; then
@@ -35,7 +35,7 @@ checkInstalledVersion()
   # version of VPN being installed has to be greater than the current VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      VPNCURRVERSION=4.9.04043
+      VPNCURRVERSION=4.10.01075
 
       if [ $(version $VPNCURRVERSION) -le $(version $VPNPREVVERSION) ]; then
         failed=true
@@ -72,7 +72,8 @@ TARROOT="vpn"
 INSTPREFIX=/opt/cisco/anyconnect
 NVM_DIR="${INSTPREFIX}/NVM"
 ROOTCERTSTORE=/opt/.cisco/certificates/ca
-ROOTCACERT="VeriSignClass3PublicPrimaryCertificationAuthority-G5.pem"
+ROOTCACERT="DigiCertAssuredIDRootCA.pem"
+ROOTCACERT_OLD="VeriSignClass3PublicPrimaryCertificationAuthority-G5.pem"
 INIT_SRC="vpnagentd_init"
 INIT="vpnagentd"
 SYSTEMD_SRC="vpnagentd.service"
@@ -91,7 +92,7 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.9.04043-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.01075-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -235,8 +236,8 @@ if [ "${TEMPDIR}" != "." ]; then
 
   echo "Extracting installation files to ${TARFILE}..."
   echo "Extracting installation files to ${TARFILE}..." >> /tmp/${LOGFNAME}
-  # "head --bytes=-1" used to remove '\n' prior to MARKER_END
-  head -n ${MARKER_END} $0 | tail -n +${MARKER} | head --bytes=-1 2>> /tmp/${LOGFNAME} > ${TARFILE} || exitInstallation 1
+
+  head -n ${MARKER_END} $0 | tail -n +${MARKER} | head -c -1 2>> /tmp/${LOGFNAME} > ${TARFILE} || exitInstallation 1
 
   echo "Unarchiving installation files to ${TEMPDIR}..."
   echo "Unarchiving installation files to ${TEMPDIR}..." >> /tmp/${LOGFNAME}
@@ -269,6 +270,9 @@ ${INSTALL} -d ${ROOTCERTSTORE} || exitInstallation 1
 echo "Installing "${NEWTEMP}/${ROOTCACERT} >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 444 ${NEWTEMP}/${ROOTCACERT} ${ROOTCERTSTORE} || exitInstallation 1
 
+echo "Installing "${NEWTEMP}/${ROOTCACERT_OLD} >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 444 ${NEWTEMP}/${ROOTCACERT_OLD} ${ROOTCERTSTORE} || exitInstallation 1
+
 echo "Installing "${NEWTEMP}/vpn_uninstall.sh >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/vpn_uninstall.sh ${BINDIR} || exitInstallation 1
 
@@ -374,6 +378,13 @@ else
     echo "${NEWTEMP}/libboost_chrono.so does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/libboost_regex.so" ]; then
+    echo "Installing "${NEWTEMP}/libboost_regex.so >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 755 ${NEWTEMP}/libboost_regex.so ${LIBDIR} || exit 1
+else
+    echo "${NEWTEMP}/libboost_regex.so does not exist. It will not be installed."
+fi
+
 if [ -f "${NEWTEMP}/vpnui" ]; then
     echo "Installing "${NEWTEMP}/vpnui >> /tmp/${LOGFNAME}
     ${INSTALL} -o root -m 755 ${NEWTEMP}/vpnui ${BINDIR} || exitInstallation 1
@@ -488,6 +499,13 @@ else
     echo "${NEWTEMP}/vpndownloader-cli does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/libacdownloader.so" ]; then
+    echo "Installing "${NEWTEMP}/libacdownloader.so >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 755 ${NEWTEMP}/libacdownloader.so ${PLUGINDIR} || exit 1
+else
+    echo "${NEWTEMP}/libacdownloader.so does not exist. It will not be installed."
+fi
+
 echo "Installing "${NEWTEMP}/acinstallhelper >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/acinstallhelper ${BINDIR} || exitInstallation 1
 
@@ -545,6 +563,10 @@ DISABLE_VPN_TAG="DisableVPN"
 DISABLE_FEEDBACK_TAG="DisableCustomerExperienceFeedback"
 
 BYPASS_DOWNLOADER_TAG="BypassDownloader"
+RESTRICT_SCRIPT_WEBDEPLOY_TAG="RestrictScriptWebDeploy"
+RESTRICT_HELP_WEBDEPLOY_TAG="RestrictHelpWebDeploy"
+RESTRICT_RESOURCE_WEBDEPLOY_TAG="RestrictResourceWebDeploy"
+RESTRICT_LOCALIZATION_WEBDEPLOY_TAG="RestrictLocalizationWebDeploy"
 FIPS_MODE_TAG="FipsMode"
 RESTRICT_PREFERENCE_CACHING_TAG="RestrictPreferenceCaching"
 RESTRICT_TUNNEL_PROTOCOLS_TAG="RestrictTunnelProtocols"
@@ -560,6 +582,10 @@ ALLOW_VPN_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowVPNProfileUpdatesFromAnyServ
 ALLOW_MGMT_VPN_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowManagementVPNProfileUpdatesFromAnyServer"
 ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowISEProfileUpdatesFromAnyServer"
 ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG="AllowServiceProfileUpdatesFromAnyServer"
+ALLOW_SCRIPT_UPDATES_FROM_ANY_SERVER_TAG="AllowScriptUpdatesFromAnyServer"
+ALLOW_HELP_UPDATES_FROM_ANY_SERVER_TAG="AllowHelpUpdatesFromAnyServer"
+ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER_TAG="AllowResourceUpdatesFromAnyServer"
+ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER_TAG="AllowLocalizationUpdatesFromAnyServer"
 AUTHORIZED_SERVER_LIST_TAG="AuthorizedServerList"
 
 if $IS_PRE_DEPLOY; then
@@ -576,6 +602,10 @@ if [ -f "${TRANSFORM_FILE}" ] ; then
     DISABLE_FEEDBACK=$(getProperty "${TRANSFORM_FILE}" ${DISABLE_FEEDBACK_TAG} "true" )
 
     BYPASS_DOWNLOADER=$(getProperty "${TRANSFORM_FILE}" ${BYPASS_DOWNLOADER_TAG})
+    RESTRICT_SCRIPT_WEBDEPLOY=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_SCRIPT_WEBDEPLOY_TAG})
+    RESTRICT_HELP_WEBDEPLOY=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_HELP_WEBDEPLOY_TAG})
+    RESTRICT_RESOURCE_WEBDEPLOY=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_RESOURCE_WEBDEPLOY_TAG})
+    RESTRICT_LOCALIZATION_WEBDEPLOY=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_LOCALIZATION_WEBDEPLOY_TAG})
     FIPS_MODE=$(getProperty "${TRANSFORM_FILE}" ${FIPS_MODE_TAG})
     RESTRICT_PREFERENCE_CACHING=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_PREFERENCE_CACHING_TAG})
     RESTRICT_TUNNEL_PROTOCOLS=$(getProperty "${TRANSFORM_FILE}" ${RESTRICT_TUNNEL_PROTOCOLS_TAG})
@@ -591,6 +621,10 @@ if [ -f "${TRANSFORM_FILE}" ] ; then
     ALLOW_MGMT_VPN_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_MGMT_VPN_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
     ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
     ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_SCRIPT_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_SCRIPT_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_HELP_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_HELP_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER_TAG})
+    ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER=$(getProperty "${TRANSFORM_FILE}" ${ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER_TAG})
     AUTHORIZED_SERVER_LIST=$(getProperty "${TRANSFORM_FILE}" ${AUTHORIZED_SERVER_LIST_TAG})
 fi
 
@@ -606,6 +640,10 @@ fi
 
 # generate default AnyConnect Local Policy file if it doesn't already exist
 ${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
+                                    rswd=${RESTRICT_SCRIPT_WEBDEPLOY:-false} \
+                                    rhwd=${RESTRICT_HELP_WEBDEPLOY:-false} \
+                                    rrwd=${RESTRICT_RESOURCE_WEBDEPLOY:-false} \
+                                    rlwd=${RESTRICT_LOCALIZATION_WEBDEPLOY:-false} \
                                     fm=${FIPS_MODE:-false} \
                                     rpc=${RESTRICT_PREFERENCE_CACHING:-false} \
                                     rtp=${RESTRICT_TUNNEL_PROTOCOLS:-false} \
@@ -621,6 +659,10 @@ ${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
                                     upmv=${ALLOW_MGMT_VPN_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
                                     upip=${ALLOW_ISE_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
                                     upsp=${ALLOW_SERVICE_PROFILE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upscr=${ALLOW_SCRIPT_UPDATES_FROM_ANY_SERVER:-true} \
+                                    uphlp=${ALLOW_HELP_UPDATES_FROM_ANY_SERVER:-true} \
+                                    upres=${ALLOW_RESOURCE_UPDATES_FROM_ANY_SERVER:-true} \
+                                    uploc=${ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER:-true} \
                                     upal=${AUTHORIZED_SERVER_LIST}
 
 # Attempt to install the init script in the proper place
